@@ -3,6 +3,10 @@ from bs4 import BeautifulSoup as soup
 
 
 def news():
+    """
+    This method will tells top 15 current NEWS
+    :return: list / bool
+    """
     try:
         news_url = "https://news.google.com/news/rss"
         Client = urlopen(news_url)
@@ -16,4 +20,4 @@ def news():
         return li
     except Exception as e:
         print(e)
-        return False
\ No newline at end of file
+        return False
